==> segatex-8.000.tar.gz: segatex-8.000/src/semanage_core_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECOREPROCESS_H
#define SEMANAGECOREPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
//#include <qvaluevector.h> 
#include <qlabel.h> 
#include <q3textedit.h>
//Added by qt3to4:
#include <Q3VBoxLayout>
#include <Q3HBoxLayout>


class QLayout;
class Q3TextEdit;
class QLineEdit;
class QPushButton;
class Q3Process;

class SemanageCoreProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreProcess(QWidget *parent = 0, const char *name = 0);
	//int i;
	//QString outputfile_str_common;
	//QString outputfile_str_common2;
	//QString textEdit1_str;
public slots:
	//void semanage_core_base_process();
signals:
//	void semanage_core_prosess_close_button_clicked();
protected:
private slots:
	void semanage_core_base_process();
	//void close_button_clicked();
	void make_button_clicked();
	void install_button_clicked();
	void update_button_clicked();
	void remove_button_clicked();
	//void make_button_clicked_process(QString textEdit1_str);
	//void install_button_clicked_process(QString textEdit1_str);
	//void update_button_clicked_process(QString textEdit1_str);
	//void remove_button_clicked_process(QString textEdit1_str);
	void readFromOutputFile();
	//void readFromOutputFile2();
public:
private:
	QPushButton *makeButton;
	QPushButton *installButton;
	QPushButton *updateButton;
	QPushButton *removeButton;
	QPushButton *closeButton;
	Q3TextEdit *textEdit1;
	Q3TextEdit *textEdit2;
	Q3TextEdit *textEdit3;
	Q3Process *process;

	Q3VBoxLayout *mainLayout;
	Q3VBoxLayout *upperLayout;
	Q3VBoxLayout *underLayout;
	Q3HBoxLayout *leftLayout;
	//QHBoxLayout *middleLayout;
	Q3HBoxLayout *rightLayout;
	Q3HBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLineEdit *semanageEditLineEdit;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit_str_pp;
};

#endif

==> segatex-8.630.tar.gz: segatex-8.630/src/semanage_core_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEMANAGECOREPROCESS_H
#define SEMANAGECOREPROCESS_H

#include <QDialog>
#include <QLayout>
#include <QDir> 
#include <QLabel> 
#include <QTextEdit>
#include <QVBoxLayout>
#include <QHBoxLayout>

class QLayout;
class QTextEdit;
class QLineEdit;
class QPushButton;
class QProcess;

class SemanageCoreProcess: public QDialog 
{
	Q_OBJECT
public:
	SemanageCoreProcess(QWidget *parent = 0, const char *name = 0);
	//int i;
	//QString outputfile_str_common;
	//QString outputfile_str_common2;
	//QString textEdit1_str;
public slots:
	//void semanage_core_base_process();
signals:
//	void semanage_core_prosess_close_button_clicked();
protected:
private slots:
	void semanage_core_base_process();
	//void close_button_clicked();
	void make_button_clicked();
	void install_button_clicked();
	void update_button_clicked();
	void remove_button_clicked();
	//void make_button_clicked_process(QString textEdit1_str);
	//void install_button_clicked_process(QString textEdit1_str);
	//void update_button_clicked_process(QString textEdit1_str);
	//void remove_button_clicked_process(QString textEdit1_str);
	void readFromOutputFile();
	//void readFromOutputFile2();
public:
private:
	QPushButton *makeButton;
	QPushButton *installButton;
	QPushButton *updateButton;
	QPushButton *removeButton;
	QPushButton *closeButton;
	QTextEdit *textEdit1;
	QTextEdit *textEdit2;
	QTextEdit *textEdit3;
	QProcess *process;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QVBoxLayout *underLayout;
	QHBoxLayout *leftLayout;
	//QHBoxLayout *middleLayout;
	QHBoxLayout *rightLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;

        QString radiobutton_obj_str;
        QLabel *semanageEditLabel;
        QLineEdit *semanageEditLineEdit;
        QString semanageEditLineEdit_str;
        QString semanageEditLineEdit_str_pp;
};

#endif
